rule win_udpos_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.udpos."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.udpos"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8bc8 23cf 0bf1 8b4dfc 03d6 0353fc 8bf0 }
            // n = 7, score = 100
            //   8bc8                 | mov                 ecx, eax
            //   23cf                 | and                 ecx, edi
            //   0bf1                 | or                  esi, ecx
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   03d6                 | add                 edx, esi
            //   0353fc               | add                 edx, dword ptr [ebx - 4]
            //   8bf0                 | mov                 esi, eax

        $sequence_1 = { 8b4dfc 83c404 5f 8bc3 33cd }
            // n = 5, score = 100
            //   8b4dfc               | mov                 ecx, dword ptr [ebp - 4]
            //   83c404               | add                 esp, 4
            //   5f                   | pop                 edi
            //   8bc3                 | mov                 eax, ebx
            //   33cd                 | xor                 ecx, ebp

        $sequence_2 = { 52 e8???????? 83c418 833d????????00 0f8596000000 8d85ccf3ffff 50 }
            // n = 7, score = 100
            //   52                   | push                edx
            //   e8????????           |                     
            //   83c418               | add                 esp, 0x18
            //   833d????????00       |                     
            //   0f8596000000         | jne                 0x9c
            //   8d85ccf3ffff         | lea                 eax, [ebp - 0xc34]
            //   50                   | push                eax

        $sequence_3 = { 8888f8e84000 40 ebe6 ff35???????? ff15???????? 85c0 7513 }
            // n = 7, score = 100
            //   8888f8e84000         | mov                 byte ptr [eax + 0x40e8f8], cl
            //   40                   | inc                 eax
            //   ebe6                 | jmp                 0xffffffe8
            //   ff35????????         |                     
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax
            //   7513                 | jne                 0x15

        $sequence_4 = { 7e1e 8d575c 85f6 7517 6639944dfcfdffff 7508 be01000000 }
            // n = 7, score = 100
            //   7e1e                 | jle                 0x20
            //   8d575c               | lea                 edx, [edi + 0x5c]
            //   85f6                 | test                esi, esi
            //   7517                 | jne                 0x19
            //   6639944dfcfdffff     | cmp                 word ptr [ebp + ecx*2 - 0x204], dx
            //   7508                 | jne                 0xa
            //   be01000000           | mov                 esi, 1

        $sequence_5 = { 51 e8???????? a1???????? 8b3d???????? 83c418 }
            // n = 5, score = 100
            //   51                   | push                ecx
            //   e8????????           |                     
            //   a1????????           |                     
            //   8b3d????????         |                     
            //   83c418               | add                 esp, 0x18

        $sequence_6 = { 7e0d 83f809 7e08 a1???????? 8b7024 56 8d4d9c }
            // n = 7, score = 100
            //   7e0d                 | jle                 0xf
            //   83f809               | cmp                 eax, 9
            //   7e08                 | jle                 0xa
            //   a1????????           |                     
            //   8b7024               | mov                 esi, dword ptr [eax + 0x24]
            //   56                   | push                esi
            //   8d4d9c               | lea                 ecx, [ebp - 0x64]

        $sequence_7 = { e8???????? 68f4010000 6a00 8d8dc8fcffff 51 e9???????? }
            // n = 6, score = 100
            //   e8????????           |                     
            //   68f4010000           | push                0x1f4
            //   6a00                 | push                0
            //   8d8dc8fcffff         | lea                 ecx, [ebp - 0x338]
            //   51                   | push                ecx
            //   e9????????           |                     

        $sequence_8 = { ffd6 8d953cffffff 52 8d85e0f8ffff 50 ffd6 }
            // n = 6, score = 100
            //   ffd6                 | call                esi
            //   8d953cffffff         | lea                 edx, [ebp - 0xc4]
            //   52                   | push                edx
            //   8d85e0f8ffff         | lea                 eax, [ebp - 0x720]
            //   50                   | push                eax
            //   ffd6                 | call                esi

        $sequence_9 = { 40 3bc3 7cef 8b85a0feffff 50 e8???????? }
            // n = 6, score = 100
            //   40                   | inc                 eax
            //   3bc3                 | cmp                 eax, ebx
            //   7cef                 | jl                  0xfffffff1
            //   8b85a0feffff         | mov                 eax, dword ptr [ebp - 0x160]
            //   50                   | push                eax
            //   e8????????           |                     

    condition:
        7 of them and filesize < 163840
}